@@ -1,4 +1,4 @@
-# Copyright (C) 2010,2011,2012 The ESPResSo project
+# Copyright (C) 2010,2011,2012,2013 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #  Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -79,6 +79,8 @@ proc blockfile_read_auto_particles {channel read auto} {
                 set mass $idx; incr idx }
             "^vi"     { if {![regexp "^$i" "virtual"]} { error " $i is not a particle property" }
                 set virtual $idx; incr idx }
+            "^vs"     { if {![regexp "^$i" "vs_relative"]} { error " $i is not a particle property" }
+                set vs_relative $idx; incr idx 2 }
 	    "^q$"     { set q $idx; incr idx }
 	    "^v"      { if {![regexp "^$i" "v"]} { error " $i is not a particle property" }
 		set v $idx; incr idx 3 }
@@ -115,6 +117,8 @@ proc blockfile_read_auto_particles {channel read auto} {
              mass \[lindex \$line $mass\]" }
     if {[info exists virtual]} { set cmd "$cmd \
              virtual \[lindex \$line $virtual\]" }
+    if {[info exists vs_relative]} { set cmd "$cmd \
+             vs_relative \[lindex \$line $vs_relative\] \[lindex \$line [expr $vs_relative +1]\]" }
     if {[info exists v]} { set cmd "$cmd \
              v  \[lindex \$line $v\] \[lindex \$line [expr $v + 1]\] \[lindex \$line [expr $v + 2]\]"
     }
