@@ -1,4 +1,4 @@
-# Copyright (C) 2010,2011,2012 The ESPResSo project
+# Copyright (C) 2010,2011,2012,2013 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #   Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -46,36 +46,36 @@ set quiet 0
 foreach arg $argv { if {$arg == "-quiet"} { set quiet 1 } }
 
 if {!$quiet} {
-    puts "*******************************************************"
-    puts "*                                                     *"
-    puts "*                    - ESPResSo -                     *"
-    puts "*                    ============                     *"
-    puts "*        A Parallel Molecular Dynamics Program        *"
-    puts "*                                                     *"
-    puts "* (c) 2010,2011,2012                                  *"
-    puts "* The ESPResSo project                                *"
-    puts "*                                                     *"
-    puts "* (c) 2002,2003,2004,2005,2006,2007,2008,2009,2010    *"
-    puts "* Max-Planck-Institute for Polymer Research           *"
-    puts "* Mainz, Germany                                      *"
-    puts "*                                                     *"
-    puts "*******************************************************"
-    puts ""
-    puts "This is [code_info version]."
-    puts ""
-    puts "ESPResSo is free software: you can redistribute it and/or modify"
-    puts "it under the terms of the GNU General Public License as published by"
-    puts "the Free Software Foundation, either version 3 of the License, or"
-    puts "(at your option) any later version."
-    puts ""
-    puts "ESPResSo is distributed in the hope that it will be useful,"
-    puts "but WITHOUT ANY WARRANTY; without even the implied warranty of"
-    puts "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the"
-    puts "GNU General Public License for more details."
-    puts "" 
-    puts "You should have received a copy of the GNU General Public License"
-    puts "along with this program.  If not, see <http://www.gnu.org/licenses/>."
-    puts ""
+    puts stderr "*******************************************************"
+    puts stderr "*                                                     *"
+    puts stderr "*                    - ESPResSo -                     *"
+    puts stderr "*                    ============                     *"
+    puts stderr "*        A Parallel Molecular Dynamics Program        *"
+    puts stderr "*                                                     *"
+    puts stderr "* (c) 2010,2011,2012                                  *"
+    puts stderr "* The ESPResSo project                                *"
+    puts stderr "*                                                     *"
+    puts stderr "* (c) 2002,2003,2004,2005,2006,2007,2008,2009,2010    *"
+    puts stderr "* Max-Planck-Institute for Polymer Research           *"
+    puts stderr "* Mainz, Germany                                      *"
+    puts stderr "*                                                     *"
+    puts stderr "*******************************************************"
+    puts stderr ""
+    puts stderr "This is [code_info version]."
+    puts stderr ""
+    puts stderr "ESPResSo is free software: you can redistribute it and/or modify"
+    puts stderr "it under the terms of the GNU General Public License as published by"
+    puts stderr "the Free Software Foundation, either version 3 of the License, or"
+    puts stderr "(at your option) any later version."
+    puts stderr ""
+    puts stderr "ESPResSo is distributed in the hope that it will be useful,"
+    puts stderr "but WITHOUT ANY WARRANTY; without even the implied warranty of"
+    puts stderr "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the"
+    puts stderr "GNU General Public License for more details."
+    puts stderr "" 
+    puts stderr "You should have received a copy of the GNU General Public License"
+    puts stderr "along with this program.  If not, see <http://www.gnu.org/licenses/>."
+    puts stderr ""
 }
 
 # Check to see if the user specified a packages directory
@@ -105,8 +105,3 @@ source statistics.tcl
 source ABHmath.tcl
 source vtf.tcl
 source dielectrics.tcl
-
-# make available readline if Espresso is interactive
-if {$tcl_interactive} {
-	source tclline.tcl
-}
