@@ -1,12 +1,5 @@
-#############################################################
-#                                                           #
-# vtf.tcl                                                   #
-# =======                                                   #
-#                                                           #
-# Functions that allow writing VTF files.                   #
-#                                                           #
-#############################################################
 #
+# Copyright (C) 2012,2013 The ESPResSo project
 # Copyright (C) 2006,2007,2008,2009,2010,2011 Olaf Lenz
 #  
 # This file is part of ESPResSo.
@@ -24,6 +17,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>. 
 #  
+#############################################################
+#                                                           #
+# vtf.tcl                                                   #
+# =======                                                   #
+#                                                           #
+# Functions that allow writing VTF files.                   #
+#                                                           #
+#############################################################
 
 # Write the structure information of the current system to the given file
 # OPTIONS:
@@ -97,6 +98,7 @@ proc writevsf { file args } {
     set typedesc {}
     set radius {}
     set short 0
+    set no_charges 0
 
     # Parse options
     for { set argnum 0 } { $argnum < [llength $args] } { incr argnum } {
@@ -111,6 +113,9 @@ proc writevsf { file args } {
 		set radius $val
 		incr argnum 
 	    }
+	    "ignore_charges" {
+		set no_charges 1
+	    }
 	    "verbose" { set short 0 }
 	    "short" { set short 1 }
 	    default { 
@@ -149,6 +154,7 @@ proc writevsf { file args } {
     set to 0
     set prev_type "na"
 
+    # Output the type
     for { set pid 0 } { $pid <= $max_pid } { incr pid } {
 	if { [part $pid] != "na" } then {
 	    # look for the type
@@ -169,6 +175,15 @@ proc writevsf { file args } {
     }
     puts $file [get_atom_record $from $to $prev_type]
 
+    if { [has_feature "ELECTROSTATICS"] && !$no_charges} {
+    # Output the charge
+	for { set pid 0 } { $pid <= $max_pid } { incr pid } {
+	    if { [part $pid] != "na" } then {
+		puts $file "atom [vtfpid $pid] q [part $pid print q]"
+	    }
+	}
+    }
+
     # Print bond data
     for { set from 0 } { $from <= $max_pid } { incr from } {
 	if { [part $from] != "na" } then {
