@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -34,7 +34,6 @@
 #include "forces.h"
 #include "rotation.h"
 #include "p3m.h"
-#include "ewald.h"
 #include "statistics.h"
 #include "energy.h"
 #include "pressure.h"
@@ -379,9 +378,6 @@ void mpi_bcast_event_slave(int node, int event)
     p3m_count_charged_particles();
     break;
 #endif
-  case EWALD_COUNT_CHARGES:
-    EWALD_count_charged_particles();
-    break; 
   case MAGGS_COUNT_CHARGES:
     maggs_count_charged_particles();
     break; 
@@ -1119,10 +1115,10 @@ void mpi_integrate_slave(int pnode, int task)
 /*************** REQ_BCAST_IA ************/
 void mpi_bcast_ia_params(int i, int j)
 {
-  int tablesize=0;
-
   mpi_call(mpi_bcast_ia_params_slave, i, j);
-  tablesize = tabulated_forces.max;
+#ifdef TABULATED
+  int tablesize = tabulated_forces.max;
+#endif
 #ifdef INTERFACE_CORRECTION
   int adress_tablesize = adress_tab_forces.max;
 #endif
@@ -1741,9 +1737,6 @@ void mpi_bcast_coulomb_params_slave(int node, int parm)
   case COULOMB_MAGGS:
     MPI_Bcast(&maggs, sizeof(MAGGS_struct), MPI_BYTE, 0, comm_cart); 
     break;
-  case COULOMB_EWALD:
-    MPI_Bcast(&ewald, sizeof(ewald_struct), MPI_BYTE, 0, comm_cart);
-    break;
   case COULOMB_RF:
   case COULOMB_INTER_RF:
     MPI_Bcast(&rf_params, sizeof(Reaction_field_params), MPI_BYTE, 0, comm_cart);
