@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2012 The ESPResSo project
+  Copyright (C) 2010,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -40,7 +40,6 @@
 /* include the force files */
 #include "p3m.h"
 #include "p3m-dipolar.h"
-#include "ewald.h"
 #include "lj.h"
 #include "ljgen.h"
 #include "steppot.h"
@@ -327,18 +326,6 @@ MDINLINE void add_non_bonded_pair_force(Particle *p1, Particle *p2,
       break;
     }
   #endif
-    case COULOMB_EWALD: {
-  #ifdef NPT
-      if (q1q2) {
-        double eng = add_ewald_coulomb_pair_force(p1,p2,d,dist2,dist,force);
-        if(integ_switch == INTEG_METHOD_NPT_ISO)
-  	nptiso.p_vir[0] += eng;
-      }
-  #else
-      if (q1q2) add_ewald_coulomb_pair_force(p1,p2,d,dist2,dist,force);
-  #endif
-      break;
-    }
     case COULOMB_MMM1D:
       if (q1q2) add_mmm1d_coulomb_pair_force(q1q2,d,dist2,dist,force);
       break;
