@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -40,7 +40,6 @@
 #include "rotation.h"
 #include "p3m.h"
 #include "p3m-dipolar.h"
-#include "ewald.h"
 #include "mmm1d.h"
 #include "mmm2d.h"
 #include "maggs.h"
@@ -181,10 +180,9 @@ void on_integration_start()
 #ifdef P3M
     case COULOMB_P3M:   break;
 #endif /*P3M*/
-    case COULOMB_EWALD: break;
     default: {
       char *errtext = runtime_error(128);
-      ERROR_SPRINTF(errtext,"{014 npt only works with Ewald sum or P3M} ");
+      ERROR_SPRINTF(errtext,"{014 npt only works with P3M} ");
     }
     }
 #endif /*ELECTROSTATICS*/
@@ -303,9 +301,6 @@ void on_observable_calc()
       p3m_count_charged_particles();
       break;
 #endif
-    case COULOMB_EWALD:
-      EWALD_count_charged_particles();
-      break;
     case COULOMB_MAGGS: 
       maggs_init(); 
       break;
@@ -369,9 +364,6 @@ void on_coulomb_change()
     p3m_init();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_init();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
@@ -460,9 +452,6 @@ void on_resort_particles()
   case COULOMB_MMM2D:
     MMM2D_on_resort_particles();
     break;
-  case COULOMB_EWALD:
-    EWALD_on_resort_particles();
-    break;
   default: break;
   }
 #endif /* ifdef ELECTROSTATICS */
@@ -486,9 +475,6 @@ void on_boxl_change() {
     p3m_scaleby_box_l();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_scaleby_box_l();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
@@ -516,6 +502,9 @@ void on_boxl_change() {
 #ifdef LB
   if(lattice_switch & LATTICE_LB) {
     lb_init();
+#ifdef LB_BOUNDARIES
+    lb_init_boundaries();
+#endif
   }
 #endif
 }
@@ -541,9 +530,6 @@ void on_cell_structure_change()
     p3m_init();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_init();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
