@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -101,8 +101,6 @@
   #define COULOMB_MMM2D   5
   /** Coulomb method is "Maggs" */
   #define COULOMB_MAGGS   6
-  /** Coulomb method is standard Ewald */
-  #define COULOMB_EWALD   7
   /** Coulomb method is P3M plus ELC. */
   #define COULOMB_ELC_P3M 8
   /** Coulomb method is Reaction-Field. */
