@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -59,7 +59,6 @@
 // Coulomb
 #include "debye_hueckel_tcl.h"
 #include "elc_tcl.h"
-#include "ewald_tcl.h"
 #include "maggs_tcl.h"
 #include "mmm1d_tcl.h"
 #include "mmm2d_tcl.h"
@@ -153,8 +152,6 @@ int tclcommand_inter_parse_coulomb(Tcl_Interp * interp, int argc, char ** argv)
   REGISTER_COULOMB("p3m", tclcommand_inter_coulomb_parse_p3m);
 #endif
 
-  REGISTER_COULOMB("ewald", tclcommand_inter_coulomb_parse_ewald); 
-
   REGISTER_COULOMB("dh", tclcommand_inter_coulomb_parse_dh);    
 
   if(ARG0_IS_S("rf")) return tclcommand_inter_coulomb_parse_rf(interp, argc-1, argv+1,COULOMB_RF);
@@ -477,7 +474,6 @@ int tclprint_to_result_CoulombIA(Tcl_Interp *interp)
     break;
   case COULOMB_P3M: tclprint_to_result_p3m(interp); break;
 #endif
-  case COULOMB_EWALD: tclprint_to_result_EWALD(interp); break;
   case COULOMB_DH: tclprint_to_result_dh(interp); break;
   case COULOMB_RF: tclprint_to_result_rf(interp,"rf"); break;
   case COULOMB_INTER_RF: tclprint_to_result_rf(interp,"inter_rf"); break;
