@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -24,19 +24,15 @@
 
 */
 
-#include <tcl.h>
 #include <math.h>
 #include "utils.h"
 #include "particle_data.h"
-#include "parser.h"
 #include "random.h"
 #include "global.h"
-#include "communication.h"
 #include "integrate.h"
 #include "cells.h"
 #include "lb.h"
 #include "dpd.h"
-#include "lbgpu.h"
 #include "virtual_sites.h"
 
 /** \name Thermostat switches*/
@@ -78,10 +74,6 @@ extern double nptiso_gammav;
  * functions
  ************************************************/
 
-/** Implementation of the tcl command \ref tclcommand_thermostat. This function
-    allows to change the used thermostat and to set its parameters.
- */
-int tclcommand_thermostat(ClientData data, Tcl_Interp *interp, int argc, char **argv);
 
 /** initialize constants of the thermostat on
     start of integration */
@@ -119,16 +111,16 @@ MDINLINE double friction_thermV_nptiso(double p_diff) {
 }
 #endif
 
-/** Callback marking setting the temperature as outdated */
-int tclcallback_thermo_ro(Tcl_Interp *interp, void *_data);
-
 /** overwrite the forces of a particle with
     the friction term, i.e. \f$ F_i= -\gamma v_i + \xi_i\f$.
 */
 MDINLINE void friction_thermo_langevin(Particle *p)
 {
   extern double langevin_pref1, langevin_pref2;
-
+#ifdef LANGEVIN_PER_PARTICLE
+  double langevin_pref1_temp, langevin_pref2_temp;
+#endif
+  
   int j;
 #ifdef MASS
   double massf = sqrt(PMASS(*p));
@@ -159,11 +151,31 @@ MDINLINE void friction_thermo_langevin(Particle *p)
 
   for ( j = 0 ; j < 3 ; j++) {
 #ifdef EXTERNAL_FORCES
-//    if (!(p->l.ext_flag & COORD_FIXED(j)))
-    if (1==1)
+    if (!(p->l.ext_flag & COORD_FIXED(j)))
 #endif
-      {
+    {
+#ifdef LANGEVIN_PER_PARTICLE  
+      if(p->gamma >= 0.) {
+        langevin_pref1_temp = -p->gamma/time_step;
+        
+        if(p->T >= 0.)
+          langevin_pref2_temp = sqrt(24.0*p->T*p->gamma/time_step);
+        else
+          langevin_pref2_temp = sqrt(24.0*temperature*p->gamma/time_step);
+        
+        p->f.f[j] = langevin_pref1_temp*p->m.v[j]*PMASS(*p) + langevin_pref2_temp*(d_random()-0.5)*massf;
+      }
+      else {
+        if(p->T >= 0.)
+          langevin_pref2_temp = sqrt(24.0*p->T*langevin_gamma/time_step);
+        else          
+          langevin_pref2_temp = langevin_pref2;
+        
+        p->f.f[j] = langevin_pref1*p->m.v[j]*PMASS(*p) + langevin_pref2_temp*(d_random()-0.5)*massf;
+      }
+#else
       p->f.f[j] = langevin_pref1*p->m.v[j]*PMASS(*p) + langevin_pref2*(d_random()-0.5)*massf;
+#endif
     }
 #ifdef EXTERNAL_FORCES
     else p->f.f[j] = 0;
@@ -206,15 +218,15 @@ MDINLINE void friction_thermo_langevin_rotation(Particle *p)
 #endif	  
       for ( j = 0 ; j < 3 ; j++) 
       {
-	p->f.torque[j] = -langevin_gamma*p->m.omega[j] + langevin_pref2*(d_random()-0.5);
+        #ifdef ROTATIONAL_INERTIA
+	 p->f.torque[j] = -langevin_gamma*p->m.omega[j] *p->p.rinertia[j] + langevin_pref2*sqrt(p->p.rinertia[j]) * (d_random()-0.5);
+      	#else
+	 p->f.torque[j] = -langevin_gamma*p->m.omega[j] + langevin_pref2*(d_random()-0.5);
+	#endif
       }
       ONEPART_TRACE(if(p->p.identity==check_id) fprintf(stderr,"%d: OPT: LANG f = (%.3e,%.3e,%.3e)\n",this_node,p->f.f[0],p->f.f[1],p->f.f[2]));
       THERMO_TRACE(fprintf(stderr,"%d: Thermo: P %d: force=(%.3e,%.3e,%.3e)\n",this_node,p->p.identity,p->f.f[0],p->f.f[1],p->f.f[2]));
 }
 #endif
 
-#if defined(LB) || defined(LB_GPU)
-int tclcommand_thermostat_parse_lb(Tcl_Interp * interp, int argc, char ** argv);
-#endif
-
 #endif
