@@ -1,4 +1,4 @@
-# Copyright (C) 2010,2011 The ESPResSo project
+# Copyright (C) 2010,2011,2012,2013 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #    Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -79,7 +79,7 @@ set slow     0
 
 # rewrite analysis_system.data analysis_system.data2; exit 0
 
-if { [catch {
+test_catch {
     puts -nonewline "Reading the checkpoint... "; flush stdout
     checkpoint_read analysis_system.data; puts " Done."
 
@@ -281,7 +281,6 @@ if { [catch {
 	if { $maxdz > $epsilon} {puts "force of particle $maxpz: [part $maxpz pr f] != $F($maxpz)"}
 	error "force error too large"
     }
-} res ] } {
-    error_exit $res
 }
 
+exit 0
